@@ -26,7 +26,7 @@ class InteligerManager(models.Manager):
         if 0 < tempo < fim - ini:
             Query = apps.get_model('log', 'Query')
             Query(
-                tempo=fim - ini,
+                time=fim - ini,
                 query=str(qs)
             ).save()
 
