@@ -9,7 +9,7 @@ class Filial(core.models.Log):
 
     class Meta:
         #db_table = u'"core\".\"filial"'
-        db_table = u'"filial"'
+        db_table = 'filial'
 
 
 class Servico(core.models.Log):
@@ -19,7 +19,7 @@ class Servico(core.models.Log):
 
     class Meta:
         #db_table = u'"core\".\"filial_servico"'
-        db_table = u'"filial_servico"'
+        db_table = 'filial_servico'
 
 
 class RelacaoServicos(core.models.Log):
@@ -28,5 +28,5 @@ class RelacaoServicos(core.models.Log):
 
     class Meta:
         #db_table = u'"core\".\"filial_relacaoservico"'
-        db_table = u'"filial_relacaoservico"'
+        db_table = 'filial_relacaoservico'
         unique_together = ('filial', 'servico')
\ No newline at end of file
